from __future__ import print_function
import sys
import Soros
import codecs
#
# test input_file input_stream output_stream [conditional_language_codes...]
#
fil = codecs.open(sys.argv[1], encoding="UTF-8")
inp = codecs.open(sys.argv[2], encoding="UTF-8").readlines()
out = codecs.open(sys.argv[3], "wb", encoding="UTF-8")
prg = fil.read()
s = {}
langs = ["default"] + sys.argv[4:]
for l in langs:
    s[l] = Soros.compile(prg, l)
ll = len(langs)
for l in langs:
    print("Language: " + l, file=sys.stderr)
    if ll > 1:
        print("Language: " + l, file=out)
    for i in inp:
        print(s[l].run(i.strip()), file=out)




import sys
import re
try:
    unicode
except:
    unicode = lambda i, j: i

f = open(sys.argv[1],'r')
m = {}
r2 = re.compile('"')
for i in f.readlines():
    a = unicode(i.strip(), "UTF-8").split("|", 1)
    m[a[0]] = re.sub(r2, "", a[1])
f.close()
print ("titles = " + str(m))



import Soros
import sys
import codecs

out = sys.stdout

state = ""
output = ""
prefix = ""
params = []
for i in sys.argv:
    if state != "":
        if state == "prefix":
            prefix = i + " "
        elif state == "output":
            output = i
        state = ""
        continue
    if i == "-p":
        state = "prefix"
    elif i == "-o":
        state = "output"
    else:
        params += [i]

if output != "":
    out = codecs.open(output, "wb", encoding="UTF-8")

if len(params) < 2:
    print ("Usage: soros [-o file_output] [-p prefix] soros_file number(s)")
    print ("numbers may be ranges (1-100) or ranges with steps (1-100~10)")
    sys.exit()

fil = codecs.open(params[1], encoding="UTF-8")
s = Soros.compile(fil.read())
for i in params[2:]:
    b = i[1:].split("-", 1)
    b[0] = i[0] + b[0]
    if len(b) > 1:
        step = 1
        c = b[1].split("~", 1)
        if len(c) > 1:
            b[1] = c[0]
            step = int(c[1])
        for j in range(int(b[0]), int(b[1]) + 1, step):
            try:
                print (s.run(prefix + str(j)))
            except:
                print >>out, s.run(prefix + str(j))

    else:
        try:
            print (s.run(prefix + i))
        except:
            print >>out, s.run(prefix + i)



import uno
import unohelper

def createInstance( ctx ):
    # NumberText uses a new type, importing it at the top of this file
    # leads to a failure during adding the extension to OOo 
    import org.Numbertext
    return org.Numbertext.NUMBERTEXT( ctx )

# pythonloader looks for a static g_ImplementationHelper variable
g_ImplementationHelper = unohelper.ImplementationHelper()
g_ImplementationHelper.addImplementation( \
        createInstance,"org.numbertext",
        ("com.sun.star.sheet.AddIn",),)



import sys
f = open(sys.argv[1],'r')
print ("# -*- encoding: UTF-8 -*-")
print ("r\"\"\"")
sys.stdout.writelines([i.strip() + '\n' for i in f.readlines()])
print ("\"\"\"")
print ("from __future__ import unicode_literals")
